==> julia-git-diffeqnoiseprocess-src-5.24.1-1-any.pkg.tar.zst: usr/share/julia/arch-site/DiffEqNoiseProcess/README.md <==
# DiffEqNoiseProcess.jl

[![Join the chat at https://julialang.zulipchat.com #sciml-bridged](https://img.shields.io/static/v1?label=Zulip&message=chat&color=9558b2&labelColor=389826)](https://julialang.zulipchat.com/#narrow/stream/279055-sciml-bridged)
[![Global Docs](https://img.shields.io/badge/docs-SciML-blue.svg)](https://docs.sciml.ai/DiffEqNoiseProcess/stable/)

[![codecov](https://codecov.io/gh/SciML/DiffEqNoiseProcess.jl/branch/master/graph/badge.svg)](https://codecov.io/gh/SciML/DiffEqNoiseProcess.jl)
[![Build Status](https://github.com/SciML/DiffEqNoiseProcess.jl/workflows/CI/badge.svg)](https://github.com/SciML/DiffEqNoiseProcess.jl/actions?query=workflow%3ACI)

[![ColPrac: Contributor's Guide on Collaborative Practices for Community Packages](https://img.shields.io/badge/ColPrac-Contributor%27s%20Guide-blueviolet)](https://github.com/SciML/ColPrac)
[![SciML Code Style](https://img.shields.io/static/v1?label=code%20style&message=SciML&color=9558b2&labelColor=389826)](https://github.com/SciML/SciMLStyle)

DiffEqNoiseProcess.jl is a component package in the DifferentialEquations ecosystem.
It holds the tools for developing noise processes for differential equations.
While completely independent and usable on its own, users interested in using this
functionality should check out [DifferentialEquations.jl](https://github.com/SciML/DifferentialEquations.jl).

## Tutorials and Documentation

For information on using the package,
[see the stable documentation](https://docs.sciml.ai/DiffEqNoiseProcess/stable/). Use the
[in-development documentation](https://docs.sciml.ai/DiffEqNoiseProcess/dev/) for the version of
the documentation, which contains the unreleased features.

==> julia-git-diffeqnoiseprocess-src-5.26.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/DiffEqNoiseProcess/README.md <==
# DiffEqNoiseProcess.jl

[![Join the chat at https://julialang.zulipchat.com #sciml-bridged](https://img.shields.io/static/v1?label=Zulip&message=chat&color=9558b2&labelColor=389826)](https://julialang.zulipchat.com/#narrow/stream/279055-sciml-bridged)
[![Global Docs](https://img.shields.io/badge/docs-SciML-blue.svg)](https://docs.sciml.ai/DiffEqNoiseProcess/stable/)

[![codecov](https://codecov.io/gh/SciML/DiffEqNoiseProcess.jl/branch/master/graph/badge.svg)](https://codecov.io/gh/SciML/DiffEqNoiseProcess.jl)
[![Build Status](https://github.com/SciML/DiffEqNoiseProcess.jl/workflows/CI/badge.svg)](https://github.com/SciML/DiffEqNoiseProcess.jl/actions?query=workflow%3ACI)

[![ColPrac: Contributor's Guide on Collaborative Practices for Community Packages](https://img.shields.io/badge/ColPrac-Contributor%27s%20Guide-blueviolet)](https://github.com/SciML/ColPrac)
[![SciML Code Style](https://img.shields.io/static/v1?label=code%20style&message=SciML&color=9558b2&labelColor=389826)](https://github.com/SciML/SciMLStyle)

DiffEqNoiseProcess.jl is a component package in the DifferentialEquations.jl ecosystem.
It provides tools for creating noise processes for stochastic differential equations.
While completely independent and usable on its own, users interested in using this
functionality should check out [DifferentialEquations.jl](https://github.com/SciML/DifferentialEquations.jl).

## Tutorials and Documentation

For information on using the package,
[see the stable documentation](https://docs.sciml.ai/DiffEqNoiseProcess/stable/). Use the
[in-development documentation](https://docs.sciml.ai/DiffEqNoiseProcess/dev/) for the version of
the documentation, which contains the unreleased features.
